==> webcamoid_7.0.0.orig.tar.gz: webcamoid-7.0.0/libAvKys/Plugins/MultiSink/share/ts/gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>StreamOptions</name>
    <message>
        <location filename="../qml/StreamOptions.qml" line="28"/>
        <source>Stream #%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="29"/>
        <source>Stream #%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="66"/>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="86"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="106"/>
        <source>GOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="111"/>
        <source>Separation between keyframes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="126"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="130"/>
        <source>{&quot;opt1&quot;: &quot;val1&quot;, &quot;opt2&quot;: &quot;val2&quot;, &quot;opt3&quot;: &quot;val3&quot;...}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="153"/>
        <source>Size of the audio (bits) / duration (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="174"/>
        <source>Size of the video (bits) / duration (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="120"/>
        <source>Output format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="142"/>
        <source>File extentions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="148"/>
        <source>This output format has not specific extentions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="153"/>
        <source>Format options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="158"/>
        <source>Encoding options for this format.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> webcamoid_7.2.1+dfsg1.orig.tar.gz: webcamoid-7.2.1+dfsg1/libAvKys/Plugins/MultiSink/share/ts/gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>StreamOptions</name>
    <message>
        <location filename="../qml/StreamOptions.qml" line="27"/>
        <source>Stream #%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="28"/>
        <source>Stream #%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="65"/>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="85"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="105"/>
        <source>GOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="110"/>
        <source>Separation between keyframes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="125"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="129"/>
        <source>{&quot;opt1&quot;: &quot;val1&quot;, &quot;opt2&quot;: &quot;val2&quot;, &quot;opt3&quot;: &quot;val3&quot;...}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="152"/>
        <source>Size of the audio (bits) / duration (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/StreamOptions.qml" line="173"/>
        <source>Size of the video (bits) / duration (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="119"/>
        <source>Output format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="141"/>
        <source>File extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="147"/>
        <source>This output format has not specific extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="152"/>
        <source>Format options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="157"/>
        <source>Encoding options for this format.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
